/**
 * Created by lion on 8/2/16.
 */

import React, {PropTypes, Component}  from 'react';
import {TimelineMax, TweenMax} from 'gsap';
import CategorySwitch from './CategorySwitch';
import ToolsContainer from './ToolsContainer';
import AssistItem from './AssistItem';

import {SIZE} from './context';
// import transitions from '../styles/transitions';
import ToolBoxEvents from '../events/ToolBoxEvents'

import _ from 'underscore';
import PubSub from 'pubsub-js';

function getStyles(props) {

    return {
        container: {

            display: 'flex',
            flexDirection: 'column',
            justifyContent: 'space-between',
            alignItems: 'center',

            flexShrink:0,

            boxSizing:'border-box',

            margin: '20px 0',
            padding: '20px 0',
            width: '100%',
            border: 'solid 1px #000',
            // overflow: 'hidden',

            // transition:transitions.easeOut('.4s')
        },
        switch: {
            // backgroundColor: props.bgColor ? props.bgColor : lightBlack,
            // width: '100%',
            // height: '100%',
            // minWidth:1000
        }
    };
}

class CategoryContainer extends Component {

    constructor() {
        super();
        this.timeline = new TimelineLite({paused: true});
        this.element = {
            container: {}, tools: {bg: {}, items: []}, assist: []
        }

        this.isOpen = false;
    }

    static
    propTypes = {

        clickHandle: PropTypes.func,

        type: PropTypes.string,

        active: PropTypes.bool,

        switchStyle: PropTypes.object,

        tools: PropTypes.object,

        assist: PropTypes.object,

        mini: PropTypes.string
    };

    static
    defaultProps = {
        type: '',
        active: false
    };

    state = {
        active: false
    };

    componentWillMount() {
        // console.log('containerMount' + this.container)
    }

    componentDidMount() {
        console.log(this.container.offsetHeight,this.container.scrollHeight)
        // console.log('containerMount' + this.props.type)
        // console.log('containerMount', this.element)
        // timeline = new TimelineLite({repeat: 0, paused: true});
        // timeline.to(this.container,{height:0,ease:Power2.easeInOut})
//.add(TweenMax.from(this.container, 1, {height: 50, ease: Power3.easeInOut}))
        this.timeline.add(TweenMax.from(this.container, 1, {height: 50, ease: Power3.easeInOut}))
            .add(TweenMax.from(this.element.tools.bg, .5, {
                height: 20,
                alpha: 0,
                ease: Power3.easeOut
            }), '-=.6')
            .add(TweenMax.staggerFrom(this.element.tools.items, .3, {autoAlpha: 0, ease: Power2.easeOut}, .1), '-=.5')
            .add(TweenMax.staggerFrom(this.element.assist, .5, {
                autoAlpha: 0,
                scale: 0.5,
                ease: Power3.easeInOut
            }, .2), '-=.5')

        console.log(this.container.offsetHeight,this.container.scrollHeight)
    }

    clickHandle() {
        // this.setState({active: !this.state.active});
        console.log('click:')
        PubSub.publish(ToolBoxEvents.TOGGLE,{type:this.props.active?'':this.props.type});
        console.log(PubSub)
    }


    render() {

        let categorySwitch, switchProps, switchStyle, toolsContainer, assistItems, assistCollection, sizeState, thisProps;

        sizeState = SIZE[this.props.mini];

        thisProps = this.props;
        // console.log('props.mini:',this.props.mini);
        console.log(this.props.mini, sizeState.width);

        // console.log(this.props.tools)
        this.containerHeight = sizeState.width * 3;
        // switchStyle = {style: {width: this.props.width, height: this.props.width}}

        switchStyle = this.props.switchStyle;
        switchProps = {
            clickHandle: this.clickHandle.bind(this),
            backgroundColor: switchStyle.backgroundColor,
            hoverColor: switchStyle.hoverColor,
            icon: switchStyle.icon,
            style: {width: sizeState.width, height: sizeState.width}
        };

        categorySwitch = <CategorySwitch {...switchProps}/>


        if (this.props.tools) {
            toolsContainer =
                <ToolsContainer
                    tools={this.props.tools}
                    backgroundColor={this.props.switchStyle.backgroundColor}
                    collection={this.element.tools}
                    sizeState={sizeState}
                />
        }

        assistCollection = this.element.assist;

        if (this.props.assist) {
            assistItems = _.map(this.props.assist, function (item, key) {

                return (
                    <AssistItem
                        key={key}
                        icon={item.icon}
                        backgroundColor={item.backgroundColor}
                        hoverColor={item.hoverColor}
                        collection={assistCollection}
                        sizeState={sizeState}
                    />
                );
            })

            // console.log(assistItems)
        }


        const mergedData = Object.assign(this.props.switchStyle, switchStyle);

        // console.log(mergedData);
        // console.log('timeline', this.timeline)
        if (this.timeline) {

            if (this.props.active) {
                // console.log("play")
                this.timeline.timeScale(1).play();
                this.isOpen = true;

                TweenMax.to(this.container,.5,{margin:'20 0',padding:'20 0',ease:Power2.easeOut})
            } else {
                if (this.isOpen) {
                    this.timeline.timeScale(1.5).reverse();
                    this.isOpen = false;

                }
                if(this.container){
                    TweenMax.to(this.container,.5,{margin:'0 0',padding:'0 0',ease:Power2.easeOut})
                }

            }
        }

        return (
            <div
                ref={(ref) => this.container = ref}
                style={getStyles().container}>
                {categorySwitch}
                {toolsContainer}
                {assistItems}
            </div>
        )


    }
}

export
default
CategoryContainer;
