import React, {PropTypes, Component}  from 'react';
import '../style.scss';

import EventListener from 'react-event-listener';
import PubSub from 'pubsub-js'
// var fabric = require('./fabric');
import CanvasEvents from '../events/CanvasEvents'
import ToolBoxEvents from '../events/ToolBoxEvents'

import {config,configs, resizeState} from './context'
import _ from 'underscore'


import CategoryContainer from './CategoryContainer'

function getStyles(props) {

    return {
        container: {
            position: 'absolute',
            display: 'flex',
            flexDirection: 'column',
            // flexDirection: 'row',
            justifyContent: 'center',
            alignItems: 'center',

            right: 20,
            width: '100px',
            height: '100%',
            // minHeight: 700,

            overflow: 'hidden'

        }
    };
}

let activeObject;


class ToolBox extends Component {


    static propTypes = {};

    state = {
        active: false,
        mini: resizeState.MINI,
        selected: ''
    };

    onClickHandle() {
        // console.log("Click",this);
        // this.setState({active:!this.state.active});
        // console.log('changePropertys',activeObject);
        this.changePropertys();
    }

    onResetElement() {
        PubSub.publish(ToolBoxEvents.RESET);
    }

    onFinishElement() {
        PubSub.publish(ToolBoxEvents.FINISH);
    }

    onToggleCategory(msg, data) {
        console.log("SELECTED", data);
        this.setState({selected: data.type});
        // activeObject = data.object;

    }

    changePropertys() {
        if (!activeObject) return;

        console.log('changePropertys', activeObject);

        activeObject.set({left: 100, top: 300, scaleX: .5, scaleY: .5});
        activeObject.setCoords();

        activeObject.canvas.renderAll();
    }

    onSelected(msg, data) {
        // console.log("SELECTED_CLEAR",msg);
        let type;

        if (data.object) {
            console.log(data.object.type)
            switch (data.object.type) {
                case 'text':
                    type = 'information_tools'
                    break;
                case 'image':
                    type = 'background_image_tools'
                    break;
                case '':
                    type = ''
                    break;
                default:
                    type = ''
                    break;
            }
            this.setState({selected: type});
        }
    }

    onSelectedClear(msg, data) {
        // console.log("SELECTED_CLEAR",msg);
            this.setState({selected: ''});

    }

    fitToScreen() {
        let screenHeight = window.innerHeight;

        if (screenHeight <= 800) {
            this.setState({mini: resizeState.MINI})
        } else {
            this.setState({mini: resizeState.NORMAL})
        }


    }

    componentWillMount() {
        // PubSub.subscribe(ToolBoxEvents.TOGGLE, this.onToggleCategory.bind(this));
    }

    componentDidMount() {
        // console.log(transparent)
        React.Children.forEach(this.props.children, (option) => {
            console.log('option', option)
        }, this);


        this.fitToScreen();

        PubSub.subscribe(ToolBoxEvents.TOGGLE, this.onToggleCategory.bind(this));
        PubSub.subscribe(CanvasEvents.SELECTED, this.onSelected.bind(this));
        PubSub.subscribe(CanvasEvents.SELECTED_CLEAR, this.onSelectedClear.bind(this));
    }

    render() {
        const styles = getStyles(this.props);

        let thisState = this.state;

        let containerItem = _.map(configs, function (item, key) {
            // console.log(item.switchStyle);
            return (
                <CategoryContainer
                    key={key}
                    type={item.type}
                    switchStyle={item.switch}
                    tools={item.tools}
                    assist={item.assist}
                    mini={thisState.mini}
                    active={item.type === thisState.selected}
                />
            );
        })


        // let containerItem = configArr.map(function (item) {
        //     console.log(item);
        //     return (
        //        <div></div>
        //     );
        // })

        // console.log(this.state.mini);


        return (
            <div style={styles.container}>
                {containerItem}
                <EventListener target='window' onResize={this.fitToScreen.bind(this)}/>
            </div>
        );
    }
}

export  default  ToolBox;
